class NlpModel(torch.nn.Module):
    def __init__(self, *args, **kwargs):
        super().__init__()
    
    def forward():
        return NotImplemented0

    def init_model():
        """

        return:
            model instance
        """
        return NotImplemented
    
    def dump_model(dump_dir, dump_model_name):
        return NotImplemented